@@ -95,7 +95,7 @@ class GeneticOptimization:
             individual_out.fom = {key:artefacts[key] for key in artefacts if key != 'value'}
         except Exception as exc:
             print('Error while executing an individual.')
-            warnings.warn(exc)
+            warnings.warn(str(exc))
             individual_out.score = None
             individual_out.artefacts = {'value': None}
 
