@@ -24,3 +24,7 @@ class DesignVariable(DesignVariableBase):
         super().__init__(xl=xl, xu=xu, variable=variable, variable_type=variable_type)
         self.x0=x0
         self.value = value
+
+    def __repr__(self):
+        return f"DesignVariable(xl={self.xl}, xu={self.xu}, variable={self.variable}, " \
+               f"variable_type={self.variable_type})"
