@@ -20,6 +20,10 @@ class GeneticDesignVariable(DesignVariableBase):
         self._gene = _gene if _gene is not None else [0] * self.bits
         self._value = _value
 
+    def __repr__(self):
+        return f"GeneticDesignVariable(xl={self.xl}, xu={self.xu}, variable={self.variable}, " \
+               f"variable_type={self.variable_type}, bits={self.bits})"
+
     def generate_random_gene(self) -> None:
         """ Method generating a random gene for int and float design variables
 
