@@ -4,14 +4,14 @@ from dataclasses import dataclass
 import numpy as np
 
 from pymbse.optim.config.GeneticUpdateOperatorConfig import OperatorConfig
-from pymbse.optim.design_variable.Individual import Individual
+from pymbse.optim.design_variable.GeneticIndividual import GeneticIndividual
 
 
 @dataclass
 class MutationOperator:
     r_mut : float
 
-    def mutate(self, individual: Individual) -> Individual:
+    def mutate(self, individual: GeneticIndividual) -> GeneticIndividual:
         """ Method performing a bit-flip mutation with a certain probability
 
         :param individual: input individual for which the mutation is performed
